diff --git a/ImgMetadataRemover.sln b/ImgMetadataRemover.sln
index f1cfaf2..69bbf63 100644
--- a/ImgMetadataRemover.sln
+++ b/ImgMetadataRemover.sln
@@ -9,7 +9,7 @@ Project("{9A19103F-16F7-4668-BE54-9A1E7A4F7556}") = "ConsoleInterface", "Console
EndProject
Project("{9A19103F-16F7-4668-BE54-9A1E7A4F7556}") = "ImageCore.Tests", "ImageCore.Tests\ImageCore.Tests.csproj", "{8EB81515-E62C-4408-84E0-6C27E0293902}"
EndProject
-Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "UwpApplication", "UwpApplication\UwpApplication.csproj", "{2E54D610-D16D-40BF-A7C7-2092BE262779}"
+Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "WindowsApplication", "WindowsApplication\WindowsApplication.csproj", "{122A284C-5944-4AAF-B2CC-56180C882483}"
EndProject
Global
GlobalSection(SolutionConfigurationPlatforms) = preSolution
@@ -85,36 +85,36 @@ Global
{8EB81515-E62C-4408-84E0-6C27E0293902}.Release|x64.Build.0 = Release|Any CPU
{8EB81515-E62C-4408-84E0-6C27E0293902}.Release|x86.ActiveCfg = Release|Any CPU
{8EB81515-E62C-4408-84E0-6C27E0293902}.Release|x86.Build.0 = Release|Any CPU
- {2E54D610-D16D-40BF-A7C7-2092BE262779}.Debug|Any CPU.ActiveCfg = Debug|x64
- {2E54D610-D16D-40BF-A7C7-2092BE262779}.Debug|Any CPU.Build.0 = Debug|x64
- {2E54D610-D16D-40BF-A7C7-2092BE262779}.Debug|Any CPU.Deploy.0 = Debug|x64
- {2E54D610-D16D-40BF-A7C7-2092BE262779}.Debug|ARM.ActiveCfg = Debug|ARM
- {2E54D610-D16D-40BF-A7C7-2092BE262779}.Debug|ARM.Build.0 = Debug|ARM
- {2E54D610-D16D-40BF-A7C7-2092BE262779}.Debug|ARM.Deploy.0 = Debug|ARM
- {2E54D610-D16D-40BF-A7C7-2092BE262779}.Debug|ARM64.ActiveCfg = Debug|ARM64
- {2E54D610-D16D-40BF-A7C7-2092BE262779}.Debug|ARM64.Build.0 = Debug|ARM64
- {2E54D610-D16D-40BF-A7C7-2092BE262779}.Debug|ARM64.Deploy.0 = Debug|ARM64
- {2E54D610-D16D-40BF-A7C7-2092BE262779}.Debug|x64.ActiveCfg = Debug|x64
- {2E54D610-D16D-40BF-A7C7-2092BE262779}.Debug|x64.Build.0 = Debug|x64
- {2E54D610-D16D-40BF-A7C7-2092BE262779}.Debug|x64.Deploy.0 = Debug|x64
- {2E54D610-D16D-40BF-A7C7-2092BE262779}.Debug|x86.ActiveCfg = Debug|x86
- {2E54D610-D16D-40BF-A7C7-2092BE262779}.Debug|x86.Build.0 = Debug|x86
- {2E54D610-D16D-40BF-A7C7-2092BE262779}.Debug|x86.Deploy.0 = Debug|x86
- {2E54D610-D16D-40BF-A7C7-2092BE262779}.Release|Any CPU.ActiveCfg = Release|x64
- {2E54D610-D16D-40BF-A7C7-2092BE262779}.Release|Any CPU.Build.0 = Release|x64
- {2E54D610-D16D-40BF-A7C7-2092BE262779}.Release|Any CPU.Deploy.0 = Release|x64
- {2E54D610-D16D-40BF-A7C7-2092BE262779}.Release|ARM.ActiveCfg = Release|ARM
- {2E54D610-D16D-40BF-A7C7-2092BE262779}.Release|ARM.Build.0 = Release|ARM
- {2E54D610-D16D-40BF-A7C7-2092BE262779}.Release|ARM.Deploy.0 = Release|ARM
- {2E54D610-D16D-40BF-A7C7-2092BE262779}.Release|ARM64.ActiveCfg = Release|ARM64
- {2E54D610-D16D-40BF-A7C7-2092BE262779}.Release|ARM64.Build.0 = Release|ARM64
- {2E54D610-D16D-40BF-A7C7-2092BE262779}.Release|ARM64.Deploy.0 = Release|ARM64
- {2E54D610-D16D-40BF-A7C7-2092BE262779}.Release|x64.ActiveCfg = Release|x64
- {2E54D610-D16D-40BF-A7C7-2092BE262779}.Release|x64.Build.0 = Release|x64
- {2E54D610-D16D-40BF-A7C7-2092BE262779}.Release|x64.Deploy.0 = Release|x64
- {2E54D610-D16D-40BF-A7C7-2092BE262779}.Release|x86.ActiveCfg = Release|x86
- {2E54D610-D16D-40BF-A7C7-2092BE262779}.Release|x86.Build.0 = Release|x86
- {2E54D610-D16D-40BF-A7C7-2092BE262779}.Release|x86.Deploy.0 = Release|x86
+ {122A284C-5944-4AAF-B2CC-56180C882483}.Debug|Any CPU.ActiveCfg = Debug|x64
+ {122A284C-5944-4AAF-B2CC-56180C882483}.Debug|Any CPU.Build.0 = Debug|x64
+ {122A284C-5944-4AAF-B2CC-56180C882483}.Debug|Any CPU.Deploy.0 = Debug|x64
+ {122A284C-5944-4AAF-B2CC-56180C882483}.Debug|ARM.ActiveCfg = Debug|x64
+ {122A284C-5944-4AAF-B2CC-56180C882483}.Debug|ARM.Build.0 = Debug|x64
+ {122A284C-5944-4AAF-B2CC-56180C882483}.Debug|ARM.Deploy.0 = Debug|x64
+ {122A284C-5944-4AAF-B2CC-56180C882483}.Debug|ARM64.ActiveCfg = Debug|arm64
+ {122A284C-5944-4AAF-B2CC-56180C882483}.Debug|ARM64.Build.0 = Debug|arm64
+ {122A284C-5944-4AAF-B2CC-56180C882483}.Debug|ARM64.Deploy.0 = Debug|arm64
+ {122A284C-5944-4AAF-B2CC-56180C882483}.Debug|x64.ActiveCfg = Debug|x64
+ {122A284C-5944-4AAF-B2CC-56180C882483}.Debug|x64.Build.0 = Debug|x64
+ {122A284C-5944-4AAF-B2CC-56180C882483}.Debug|x64.Deploy.0 = Debug|x64
+ {122A284C-5944-4AAF-B2CC-56180C882483}.Debug|x86.ActiveCfg = Debug|x86
+ {122A284C-5944-4AAF-B2CC-56180C882483}.Debug|x86.Build.0 = Debug|x86
+ {122A284C-5944-4AAF-B2CC-56180C882483}.Debug|x86.Deploy.0 = Debug|x86
+ {122A284C-5944-4AAF-B2CC-56180C882483}.Release|Any CPU.ActiveCfg = Release|x64
+ {122A284C-5944-4AAF-B2CC-56180C882483}.Release|Any CPU.Build.0 = Release|x64
+ {122A284C-5944-4AAF-B2CC-56180C882483}.Release|Any CPU.Deploy.0 = Release|x64
+ {122A284C-5944-4AAF-B2CC-56180C882483}.Release|ARM.ActiveCfg = Release|x64
+ {122A284C-5944-4AAF-B2CC-56180C882483}.Release|ARM.Build.0 = Release|x64
+ {122A284C-5944-4AAF-B2CC-56180C882483}.Release|ARM.Deploy.0 = Release|x64
+ {122A284C-5944-4AAF-B2CC-56180C882483}.Release|ARM64.ActiveCfg = Release|arm64
+ {122A284C-5944-4AAF-B2CC-56180C882483}.Release|ARM64.Build.0 = Release|arm64
+ {122A284C-5944-4AAF-B2CC-56180C882483}.Release|ARM64.Deploy.0 = Release|arm64
+ {122A284C-5944-4AAF-B2CC-56180C882483}.Release|x64.ActiveCfg = Release|x64
+ {122A284C-5944-4AAF-B2CC-56180C882483}.Release|x64.Build.0 = Release|x64
+ {122A284C-5944-4AAF-B2CC-56180C882483}.Release|x64.Deploy.0 = Release|x64
+ {122A284C-5944-4AAF-B2CC-56180C882483}.Release|x86.ActiveCfg = Release|x86
+ {122A284C-5944-4AAF-B2CC-56180C882483}.Release|x86.Build.0 = Release|x86
+ {122A284C-5944-4AAF-B2CC-56180C882483}.Release|x86.Deploy.0 = Release|x86
EndGlobalSection
GlobalSection(SolutionProperties) = preSolution
HideSolutionNode = FALSE
diff --git a/UwpApplication/App.xaml b/UwpApplication/App.xaml
deleted file mode 100644
index dadebe1..0000000
--- a/UwpApplication/App.xaml
+++ /dev/null
@@ -1,7 +0,0 @@
-
-
-
diff --git a/UwpApplication/App.xaml.cs b/UwpApplication/App.xaml.cs
deleted file mode 100644
index 00dec71..0000000
--- a/UwpApplication/App.xaml.cs
+++ /dev/null
@@ -1,100 +0,0 @@
-using System;
-using System.Collections.Generic;
-using System.IO;
-using System.Linq;
-using System.Runtime.InteropServices.WindowsRuntime;
-using Windows.ApplicationModel;
-using Windows.ApplicationModel.Activation;
-using Windows.Foundation;
-using Windows.Foundation.Collections;
-using Windows.UI.Xaml;
-using Windows.UI.Xaml.Controls;
-using Windows.UI.Xaml.Controls.Primitives;
-using Windows.UI.Xaml.Data;
-using Windows.UI.Xaml.Input;
-using Windows.UI.Xaml.Media;
-using Windows.UI.Xaml.Navigation;
-
-namespace UwpApplication
-{
- ///
- /// Provides application-specific behavior to supplement the default Application class.
- ///
- sealed partial class App : Application
- {
- ///
- /// Initializes the singleton application object. This is the first line of authored code
- /// executed, and as such is the logical equivalent of main() or WinMain().
- ///
- public App()
- {
- this.InitializeComponent();
- this.Suspending += OnSuspending;
- }
-
- ///
- /// Invoked when the application is launched normally by the end user. Other entry points
- /// will be used such as when the application is launched to open a specific file.
- ///
- /// Details about the launch request and process.
- protected override void OnLaunched(LaunchActivatedEventArgs e)
- {
- Frame rootFrame = Window.Current.Content as Frame;
-
- // Do not repeat app initialization when the Window already has content,
- // just ensure that the window is active
- if (rootFrame == null)
- {
- // Create a Frame to act as the navigation context and navigate to the first page
- rootFrame = new Frame();
-
- rootFrame.NavigationFailed += OnNavigationFailed;
-
- if (e.PreviousExecutionState == ApplicationExecutionState.Terminated)
- {
- //TODO: Load state from previously suspended application
- }
-
- // Place the frame in the current Window
- Window.Current.Content = rootFrame;
- }
-
- if (e.PrelaunchActivated == false)
- {
- if (rootFrame.Content == null)
- {
- // When the navigation stack isn't restored navigate to the first page,
- // configuring the new page by passing required information as a navigation
- // parameter
- rootFrame.Navigate(typeof(MainPage), e.Arguments);
- }
- // Ensure the current window is active
- Window.Current.Activate();
- }
- }
-
- ///
- /// Invoked when Navigation to a certain page fails
- ///
- /// The Frame which failed navigation
- /// Details about the navigation failure
- void OnNavigationFailed(object sender, NavigationFailedEventArgs e)
- {
- throw new Exception("Failed to load Page " + e.SourcePageType.FullName);
- }
-
- ///
- /// Invoked when application execution is being suspended. Application state is saved
- /// without knowing whether the application will be terminated or resumed with the contents
- /// of memory still intact.
- ///
- /// The source of the suspend request.
- /// Details about the suspend request.
- private void OnSuspending(object sender, SuspendingEventArgs e)
- {
- var deferral = e.SuspendingOperation.GetDeferral();
- //TODO: Save application state and stop any background activity
- deferral.Complete();
- }
- }
-}
diff --git a/UwpApplication/Assets/LockScreenLogo.scale-200.png b/UwpApplication/Assets/LockScreenLogo.scale-200.png
deleted file mode 100644
index 735f57a..0000000
Binary files a/UwpApplication/Assets/LockScreenLogo.scale-200.png and /dev/null differ
diff --git a/UwpApplication/Assets/SplashScreen.scale-200.png b/UwpApplication/Assets/SplashScreen.scale-200.png
deleted file mode 100644
index 023e7f1..0000000
Binary files a/UwpApplication/Assets/SplashScreen.scale-200.png and /dev/null differ
diff --git a/UwpApplication/Assets/Square150x150Logo.scale-200.png b/UwpApplication/Assets/Square150x150Logo.scale-200.png
deleted file mode 100644
index af49fec..0000000
Binary files a/UwpApplication/Assets/Square150x150Logo.scale-200.png and /dev/null differ
diff --git a/UwpApplication/Assets/Square44x44Logo.scale-200.png b/UwpApplication/Assets/Square44x44Logo.scale-200.png
deleted file mode 100644
index ce342a2..0000000
Binary files a/UwpApplication/Assets/Square44x44Logo.scale-200.png and /dev/null differ
diff --git a/UwpApplication/Assets/Square44x44Logo.targetsize-24_altform-unplated.png b/UwpApplication/Assets/Square44x44Logo.targetsize-24_altform-unplated.png
deleted file mode 100644
index f6c02ce..0000000
Binary files a/UwpApplication/Assets/Square44x44Logo.targetsize-24_altform-unplated.png and /dev/null differ
diff --git a/UwpApplication/Assets/StoreLogo.png b/UwpApplication/Assets/StoreLogo.png
deleted file mode 100644
index 7385b56..0000000
Binary files a/UwpApplication/Assets/StoreLogo.png and /dev/null differ
diff --git a/UwpApplication/Assets/Wide310x150Logo.scale-200.png b/UwpApplication/Assets/Wide310x150Logo.scale-200.png
deleted file mode 100644
index 288995b..0000000
Binary files a/UwpApplication/Assets/Wide310x150Logo.scale-200.png and /dev/null differ
diff --git a/UwpApplication/MainPage.xaml b/UwpApplication/MainPage.xaml
deleted file mode 100644
index ee14608..0000000
--- a/UwpApplication/MainPage.xaml
+++ /dev/null
@@ -1,21 +0,0 @@
-
-
-
-
-
- test 1
- test 2
- test 3
- test 4
-
-
-
-
diff --git a/UwpApplication/Properties/AssemblyInfo.cs b/UwpApplication/Properties/AssemblyInfo.cs
deleted file mode 100644
index 20df3b9..0000000
--- a/UwpApplication/Properties/AssemblyInfo.cs
+++ /dev/null
@@ -1,29 +0,0 @@
-using System.Reflection;
-using System.Runtime.CompilerServices;
-using System.Runtime.InteropServices;
-
-// General Information about an assembly is controlled through the following
-// set of attributes. Change these attribute values to modify the information
-// associated with an assembly.
-[assembly: AssemblyTitle("UwpApplication")]
-[assembly: AssemblyDescription("")]
-[assembly: AssemblyConfiguration("")]
-[assembly: AssemblyCompany("")]
-[assembly: AssemblyProduct("UwpApplication")]
-[assembly: AssemblyCopyright("Copyright © 2022")]
-[assembly: AssemblyTrademark("")]
-[assembly: AssemblyCulture("")]
-
-// Version information for an assembly consists of the following four values:
-//
-// Major Version
-// Minor Version
-// Build Number
-// Revision
-//
-// You can specify all the values or you can default the Build and Revision Numbers
-// by using the '*' as shown below:
-// [assembly: AssemblyVersion("1.0.*")]
-[assembly: AssemblyVersion("1.0.0.0")]
-[assembly: AssemblyFileVersion("1.0.0.0")]
-[assembly: ComVisible(false)]
\ No newline at end of file
diff --git a/UwpApplication/Properties/Default.rd.xml b/UwpApplication/Properties/Default.rd.xml
deleted file mode 100644
index af00722..0000000
--- a/UwpApplication/Properties/Default.rd.xml
+++ /dev/null
@@ -1,31 +0,0 @@
-
-
-
-
-
-
-
-
-
-
-
-
-
\ No newline at end of file
diff --git a/UwpApplication/UwpApplication.csproj b/UwpApplication/UwpApplication.csproj
deleted file mode 100644
index 232d410..0000000
--- a/UwpApplication/UwpApplication.csproj
+++ /dev/null
@@ -1,177 +0,0 @@
-
-
-
-
- Debug
- x86
- {2E54D610-D16D-40BF-A7C7-2092BE262779}
- AppContainerExe
- Properties
- UwpApplication
- UwpApplication
- en-US
- UAP
- 10.0.22000.0
- 10.0.16299.0
- 14
- 512
- {A5A43C5B-DE2A-4C0C-9213-0A381AF9435A};{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}
- true
- false
-
-
- true
- bin\x86\Debug\
- DEBUG;TRACE;NETFX_CORE;WINDOWS_UWP
- ;2008
- full
- x86
- false
- prompt
- true
-
-
- bin\x86\Release\
- TRACE;NETFX_CORE;WINDOWS_UWP
- true
- ;2008
- pdbonly
- x86
- false
- prompt
- true
- true
-
-
- true
- bin\ARM\Debug\
- DEBUG;TRACE;NETFX_CORE;WINDOWS_UWP
- ;2008
- full
- ARM
- false
- prompt
- true
-
-
- bin\ARM\Release\
- TRACE;NETFX_CORE;WINDOWS_UWP
- true
- ;2008
- pdbonly
- ARM
- false
- prompt
- true
- true
-
-
- true
- bin\ARM64\Debug\
- DEBUG;TRACE;NETFX_CORE;WINDOWS_UWP
- ;2008
- full
- ARM64
- false
- prompt
- true
- true
-
-
- bin\ARM64\Release\
- TRACE;NETFX_CORE;WINDOWS_UWP
- true
- ;2008
- pdbonly
- ARM64
- false
- prompt
- true
- true
-
-
- true
- bin\x64\Debug\
- DEBUG;TRACE;NETFX_CORE;WINDOWS_UWP
- ;2008
- full
- x64
- false
- prompt
- true
-
-
- bin\x64\Release\
- TRACE;NETFX_CORE;WINDOWS_UWP
- true
- ;2008
- pdbonly
- x64
- false
- prompt
- true
- true
-
-
- PackageReference
-
-
-
- App.xaml
-
-
- MainPage.xaml
-
-
-
-
-
- Designer
-
-
-
-
-
-
-
-
-
-
-
-
-
-
- MSBuild:Compile
- Designer
-
-
- MSBuild:Compile
- Designer
-
-
-
-
- 6.2.12
-
-
-
-
-
-
-
- {10ad7910-c8aa-43ed-9231-ebe267ac270f}
- ImageCore
-
-
-
- 14.0
-
-
-
-
\ No newline at end of file
diff --git a/WindowsApplication/App.xaml b/WindowsApplication/App.xaml
new file mode 100644
index 0000000..28b4038
--- /dev/null
+++ b/WindowsApplication/App.xaml
@@ -0,0 +1,15 @@
+
+
+
+
+
+
+
+
+
+
+
diff --git a/WindowsApplication/App.xaml.cs b/WindowsApplication/App.xaml.cs
new file mode 100644
index 0000000..3f6cf7a
--- /dev/null
+++ b/WindowsApplication/App.xaml.cs
@@ -0,0 +1,51 @@
+using Microsoft.UI.Xaml;
+using Microsoft.UI.Xaml.Controls;
+using Microsoft.UI.Xaml.Controls.Primitives;
+using Microsoft.UI.Xaml.Data;
+using Microsoft.UI.Xaml.Input;
+using Microsoft.UI.Xaml.Media;
+using Microsoft.UI.Xaml.Navigation;
+using Microsoft.UI.Xaml.Shapes;
+using System;
+using System.Collections.Generic;
+using System.IO;
+using System.Linq;
+using System.Runtime.InteropServices.WindowsRuntime;
+using Windows.ApplicationModel;
+using Windows.ApplicationModel.Activation;
+using Windows.Foundation;
+using Windows.Foundation.Collections;
+
+// To learn more about WinUI, the WinUI project structure,
+// and more about our project templates, see: http://aka.ms/winui-project-info.
+
+namespace WindowsApplication
+{
+ ///
+ /// Provides application-specific behavior to supplement the default Application class.
+ ///
+ public partial class App : Application
+ {
+ ///
+ /// Initializes the singleton application object. This is the first line of authored code
+ /// executed, and as such is the logical equivalent of main() or WinMain().
+ ///
+ public App()
+ {
+ this.InitializeComponent();
+ }
+
+ ///
+ /// Invoked when the application is launched normally by the end user. Other entry points
+ /// will be used such as when the application is launched to open a specific file.
+ ///
+ /// Details about the launch request and process.
+ protected override void OnLaunched(Microsoft.UI.Xaml.LaunchActivatedEventArgs args)
+ {
+ m_window = new MainWindow();
+ m_window.Activate();
+ }
+
+ private Window m_window;
+ }
+}
diff --git a/WindowsApplication/Assets/LockScreenLogo.scale-200.png b/WindowsApplication/Assets/LockScreenLogo.scale-200.png
new file mode 100644
index 0000000..7440f0d
Binary files /dev/null and b/WindowsApplication/Assets/LockScreenLogo.scale-200.png differ
diff --git a/WindowsApplication/Assets/SplashScreen.scale-200.png b/WindowsApplication/Assets/SplashScreen.scale-200.png
new file mode 100644
index 0000000..32f486a
Binary files /dev/null and b/WindowsApplication/Assets/SplashScreen.scale-200.png differ
diff --git a/WindowsApplication/Assets/Square150x150Logo.scale-200.png b/WindowsApplication/Assets/Square150x150Logo.scale-200.png
new file mode 100644
index 0000000..53ee377
Binary files /dev/null and b/WindowsApplication/Assets/Square150x150Logo.scale-200.png differ
diff --git a/WindowsApplication/Assets/Square44x44Logo.scale-200.png b/WindowsApplication/Assets/Square44x44Logo.scale-200.png
new file mode 100644
index 0000000..f713bba
Binary files /dev/null and b/WindowsApplication/Assets/Square44x44Logo.scale-200.png differ
diff --git a/WindowsApplication/Assets/Square44x44Logo.targetsize-24_altform-unplated.png b/WindowsApplication/Assets/Square44x44Logo.targetsize-24_altform-unplated.png
new file mode 100644
index 0000000..dc9f5be
Binary files /dev/null and b/WindowsApplication/Assets/Square44x44Logo.targetsize-24_altform-unplated.png differ
diff --git a/WindowsApplication/Assets/StoreLogo.png b/WindowsApplication/Assets/StoreLogo.png
new file mode 100644
index 0000000..a4586f2
Binary files /dev/null and b/WindowsApplication/Assets/StoreLogo.png differ
diff --git a/WindowsApplication/Assets/Wide310x150Logo.scale-200.png b/WindowsApplication/Assets/Wide310x150Logo.scale-200.png
new file mode 100644
index 0000000..8b4a5d0
Binary files /dev/null and b/WindowsApplication/Assets/Wide310x150Logo.scale-200.png differ
diff --git a/WindowsApplication/MainWindow.xaml b/WindowsApplication/MainWindow.xaml
new file mode 100644
index 0000000..4971c46
--- /dev/null
+++ b/WindowsApplication/MainWindow.xaml
@@ -0,0 +1,18 @@
+
+
+
+
+
+
+
+
+
+
+
diff --git a/UwpApplication/Package.appxmanifest b/WindowsApplication/Package.appxmanifest
similarity index 58%
rename from UwpApplication/Package.appxmanifest
rename to WindowsApplication/Package.appxmanifest
index 38add63..5b40ea0 100644
--- a/UwpApplication/Package.appxmanifest
+++ b/WindowsApplication/Package.appxmanifest
@@ -2,25 +2,24 @@
+ xmlns:rescap="http://schemas.microsoft.com/appx/manifest/foundation/windows10/restrictedcapabilities"
+ IgnorableNamespaces="uap rescap">
-
-
- UwpApplication
+ WindowsApplication
nutiu
Assets\StoreLogo.png
-
+
+
@@ -30,20 +29,20 @@
+ EntryPoint="$targetentrypoint$">
-
+ Square44x44Logo="Assets\Square44x44Logo.png">
+
-
+
-
\ No newline at end of file
+
diff --git a/WindowsApplication/Properties/launchSettings.json b/WindowsApplication/Properties/launchSettings.json
new file mode 100644
index 0000000..65b7102
--- /dev/null
+++ b/WindowsApplication/Properties/launchSettings.json
@@ -0,0 +1,10 @@
+{
+ "profiles": {
+ "WindowsApplication (Package)": {
+ "commandName": "MsixPackage"
+ },
+ "WindowsApplication (Unpackaged)": {
+ "commandName": "Project"
+ }
+ }
+}
\ No newline at end of file
diff --git a/WindowsApplication/WindowsApplication.csproj b/WindowsApplication/WindowsApplication.csproj
new file mode 100644
index 0000000..045346e
--- /dev/null
+++ b/WindowsApplication/WindowsApplication.csproj
@@ -0,0 +1,37 @@
+
+
+ WinExe
+ net6.0-windows10.0.19041.0
+ 10.0.17763.0
+ WindowsApplication
+ app.manifest
+ x86;x64;arm64
+ win10-x86;win10-x64;win10-arm64
+ win10-$(Platform).pubxml
+ true
+ true
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
diff --git a/WindowsApplication/app.manifest b/WindowsApplication/app.manifest
new file mode 100644
index 0000000..cec8cae
--- /dev/null
+++ b/WindowsApplication/app.manifest
@@ -0,0 +1,15 @@
+
+
+
+
+
+
+
+ true/PM
+ PerMonitorV2, PerMonitor
+
+
+
diff --git a/UwpApplication/MainPage.xaml.cs b/WindowsApplication/MainWindow.xaml.cs
similarity index 56%
rename from UwpApplication/MainPage.xaml.cs
rename to WindowsApplication/MainWindow.xaml.cs
index 52d9535..3db72e8 100644
--- a/UwpApplication/MainPage.xaml.cs
+++ b/WindowsApplication/MainWindow.xaml.cs
@@ -1,27 +1,34 @@
-using System;
+using Microsoft.UI.Xaml;
+using System;
using System.Collections.Generic;
-using Windows.UI.Xaml;
-using Windows.UI.Xaml.Controls;
+using System.Runtime.InteropServices;
-// The Blank Page item template is documented at https://go.microsoft.com/fwlink/?LinkId=402352&clcid=0x409
+// To learn more about WinUI, the WinUI project structure,
+// and more about our project templates, see: http://aka.ms/winui-project-info.
-namespace UwpApplication
+namespace WindowsApplication
{
///
/// An empty page that can be used on its own or navigated to within a Frame.
///
- public sealed partial class MainPage : Page
+ public sealed partial class MainWindow : Window
{
- public MainPage()
+ public MainWindow()
{
this.InitializeComponent();
- Console.WriteLine("Main Page");
- this.Loaded += LoadedHandler;
+ UpdateNumberOfFilesText(0);
}
- private async void LoadedHandler(object sender, RoutedEventArgs e)
+ private async void PickFilesButton_Click(object sender, RoutedEventArgs e)
{
var folderPicker = new Windows.Storage.Pickers.FolderPicker();
+
+ // Get the current window's HWND by passing in the Window object
+ var hwnd = WinRT.Interop.WindowNative.GetWindowHandle(this);
+
+ // Associate the HWND with the file picker
+ WinRT.Interop.InitializeWithWindow.Initialize(folderPicker, hwnd);
+
folderPicker.SuggestedStartLocation = Windows.Storage.Pickers.PickerLocationId.Desktop;
folderPicker.FileTypeFilter.Add("*");
@@ -42,7 +49,13 @@ namespace UwpApplication
}
}
FilesListView.ItemsSource = fileNames;
+ UpdateNumberOfFilesText(fileNames.Count);
}
}
+
+ private void UpdateNumberOfFilesText(int nrOfFiles)
+ {
+ NumberOfFiles.Text = $"Total files {nrOfFiles}.";
+ }
}
}
@@ -1,27 +1,34 @@
{
///
- /// An empty page that can be used on its own or navigated to within a Frame.
+ /// An empty window that can be used on its own or navigated to within a Frame.
///